#ifndef NT2_INCLUDE_FUNCTIONS_IDIVFLOOR_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_IDIVFLOOR_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/idivfloor.hpp>

#endif
